@@ -41,7 +41,7 @@ canvas_item_new (GtkWidget     *widget,
   GdkPixbuf *pixbuf;
 
   stock_id = gtk_tool_button_get_stock_id (button);
-  pixbuf = gtk_widget_render_icon (widget, stock_id, GTK_ICON_SIZE_DIALOG, NULL);
+  pixbuf = gtk_widget_render_icon_pixbuf (widget, stock_id, GTK_ICON_SIZE_DIALOG);
 
   if (pixbuf)
     {
@@ -438,7 +438,7 @@ do_toolpalette (GtkWidget *do_widget)
       gtk_container_set_border_width (GTK_CONTAINER (window), 8);
 
       /* Add widgets to control the ToolPalette appearance: */
-      box = gtk_vbox_new (FALSE, 6);
+      box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
       gtk_container_add (GTK_CONTAINER (window), box);
 
       /* Orientation combo box: */
@@ -507,7 +507,7 @@ do_toolpalette (GtkWidget *do_widget)
       gtk_box_pack_start (GTK_BOX (box), combo_style, FALSE, FALSE, 0);
 
       /* Add hbox */
-      hbox = gtk_hbox_new (FALSE, 5);
+      hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
       gtk_box_pack_start (GTK_BOX (box), hbox, TRUE, TRUE, 0);
 
       /* Add and fill the ToolPalette: */
